@@ -4,6 +4,9 @@ pymatrices Package :-
 - A Python 3.x Package to implement Matrices and its properties...
 """
 
+from copy import deepcopy as _dc
+from math import sqrt as _sqrt, cos as _cos, sin as _sin, acos as _acos
+
 class matrix:
 	"""Creates a Matrix using a 2-D list"""
 
@@ -284,36 +287,138 @@ def eigenvaluesOf(matrix):
 
 	assert order[0] in (1, 2, 3), "Maximum Order is 3x3"
 
+	def F(a, b, c):
+		return ((3*c/a)-((b**2)/(a**2)))/3
+
+	def G(a, b, c, d):
+		return (((2*(b**3))/(a**3))-((9*b*c)/(a**2))+(27*d/a))/27
+
+	def H(g, f):
+		return ((g**2)/4+(f**3)/27)
+
 	if order[0] == 2:
 		S2 = determinantOf(matrix)
 
-		a, b, c = (1, -S1, S2)
+		a, b, c = 1, -S1, S2
 
 		disc = (b**2-4*a*c)**0.5
 
-		return ((-b+disc)/2*a, (-b-disc)/2*a)
+		return ((-b+disc)/(2*a), (-b-disc)/(2*a))
 	elif order[0] == 3:
 		S2 = determinantOf(matrix.minorOfValueAt(1, 1))+determinantOf(matrix.minorOfValueAt(2, 2))+determinantOf(matrix.minorOfValueAt(3, 3))
 		S3 = determinantOf(matrix)
 
 		a, b, c, d = 1, -S1, S2, -S3
 
-		d0 = b**2 - 3*a*c
-		d1 = 2*b**3 - 9*a*b*c + 27*(a**2)*d
-		sqrt = (d1**2 - 4*(d0**3))**0.5
+		if (a == 0 and b == 0):
+			return [(-d*1)/c]
 
-		c1 = ((d1+sqrt)/2)**0.33
+		elif (a == 0):
+			D = c**2 - 4*b*d
 
-		croot = (-1+3j)/2
+			if D >= 0:
+				sqrtD = _sqrt(D)
+				x1, x2 = (-c+sqrtD)/(2*b), (-c-sqrtD)/(2*b)
+			else:
+				sqrtD = _sqrt(-D)
+				x1, x2 = (-c+sqrtD*1j)/(2*b), (-c-sqrtD*1j)/(2*b)
 
-		try:
-			r1 = (-1/(3*a))*(b+c1+(d0/c1))
-			r2 = (-1/(3*a))*(b+croot*c1+(d0/croot*c1))
-			r3 = (-1/(3*a))*(b+(croot**2)*c1+(d0/(croot**2)*c1))
+			return [x1, x2]
+
+		f, g = F(a, b, c), G(a, b, c, d)
+		h = H(g, f)
+
+		if (f==0) and (g==0) and (h==0):
+			if (d/a)>=0:
+				x = -((d/(1*a))**(1/3))
+			else:
+				x = (-d/(1*a))**(1/3)
+
+			return [x]*3
+
+		elif h <= 0:
+			i = _sqrt(((g**2)/4)-h)
+			j = i**(1/3)
+			k = _acos(-(g/(2*i)))
+			L = -j
+			M = _cos(k/3)
+			N = _sqrt(3)*_sin(k/3)
+			P = -(b/(3*a))
+
+			return [round(i, 1) for i in [2*j*_cos(k/3)-(b/(3*a)), L*(M+N)+P, L*(M-N)+P]]
+
+		elif h > 0:
+			R = -(g/2)+_sqrt(h)
+			S = R**(1/3) if R>=0 else -((-R)**(1/3))
+			T = -(g/2)-_sqrt(h)
+			U = (T**(1/3)) if T>=0 else -((-T)**(1/3))
+
+			x1 = (S+U)-(b/(3*a))
+			x2 = -(S+U)/2-(b/(3*a))+(S-U)*_sqrt(3)*0.5j
+			x3 = -(S+U)/2-(b/(3*a))-(S-U)*_sqrt(3)*0.5j
+
+			res = [x1]
+
+			def compToInt(comp):
+				str_imag = str(comp.imag)
+
+				if "e" in str_imag:
+					e_ind = str_imag.find("e")
+					str_exp = str_imag[e_ind+1:]
+					exp = int(str_exp)
+
+					return comp.real if exp <= -5 else comp
+				else:
+					return comp
+
+			return [x1, compToInt(x2), compToInt(x3)]
+
+def __eigenvectorsOf(matrix):
+	res = []
+
+	def __isallzero(L1):
+		flag = True
+
+		for i in L1:
+			if i != 0:
+				flag = False
+				break
+
+		return flag
+
+	evals, order = eigenvaluesOf(matrix), matrix.order
+	matobj = [_dc(matrix.matrix) for _ in range(order[0])]
+
+	for eigval in evals:
+		mat = matobj.pop()
+
+		if isinstance(eigval, complex):
+			for i in range(order[0]):
+				for j in range(order[1]):
+					if i == j:
+						mat[i][j] = complex(mat[i][j]) - eigval
+					else:
+						mat[i][j] = complex(mat[i][j])
+		else:
+			for i in range(order[0]):
+				for j in range(order[1]):
+					if i == j:
+						mat[i][j] -= int(eigval)
+
+		veqns = list(map(__isallzero, mat))
+		eqn1, eqn2 = tuple([mat[i] for i in range(order[0]) if veqns[i]==False])[:2]
+
+		if len(eqn1) == 2:
+			pass
+		elif len(eqn1) == 3:
+			x = (eqn2[2]*eqn1[1]) - (eqn2[1]*eqn1[2])
+			y = (eqn2[0]*eqn1[2]) - (eqn2[2]*eqn1[0])
+			z = (eqn2[1]*eqn1[0]) - (eqn2[0]*eqn1[1])
+
+			res.append(createColumnMatrix((x, y, z)))
+
+	return res
 
-			return (r1, r2, r3)
-		except ZeroDivisionError:
-			return ((-b/(3*a)),)*3
 
 def inverseOf(matrix):
 	"""Returns the inverse of matrix"""
